@@ -20,6 +20,7 @@ Options:
     <short_description>             A one-line description
     <long_description>              A multi-line description
     --mkdir                         Init the repository in a new directory instead of the current directory
+    --remove-deprecated-files       remove files that were in use in previous versions of projector but are no longer necessary
 """
 
 def get_package_namespace(name):
@@ -63,11 +64,13 @@ class RepositoryPlugin(CommandPlugin):
     def _create_subdir_if_necessary(self):
         from infi.projector.helper.utils import chdir
         from os.path import exists, isdir, sep
-        from os import makedirs
+        from os import makedirs, name
         if not self.arguments.get('--mkdir'):
             yield
             return
         dirname = self.arguments.get('<project_name>') or self.arguments.get('<origin>')
+        if name == 'nt':
+            dirname = dirname.replace(sep, '/')
         dirname = (dirname if not dirname.endswith('.git') else dirname[0:-4]).split('/')[-1]
         if exists(dirname) and isdir(dirname):
             logger.debug("{} already exists".format(dirname))
@@ -208,7 +211,11 @@ class RepositoryPlugin(CommandPlugin):
         from os import curdir, path, remove
         from gitpy import LocalRepository
         repository = LocalRepository(curdir)
-        for filename in [filename for filename in ["buildout-git.cfg", "buildout-version.cfg", "buildout-pack.cfg", "buildout.in"]
+        for filename in [filename for filename in ["buildout-git.cfg",
+                                                   "buildout-version.cfg",
+                                                   "buildout-pack.cfg",
+                                                   "buildout-dist.cfg",
+                                                   "buildout.in"]
                          if path.exists(filename)]:
             logger.info("removing {}".format(filename))
             if self.arguments.get("--commit-changes", False):
